#ifndef PQCLEAN_SNTRUP761_CLEAN_CRYPTO_ENCODE_761XINT16_H
#define PQCLEAN_SNTRUP761_CLEAN_CRYPTO_ENCODE_761XINT16_H

#include <stdint.h>
#define PQCLEAN_SNTRUP761_CLEAN_crypto_encode_761xint16_STRBYTES 1522
#define PQCLEAN_SNTRUP761_CLEAN_crypto_encode_761xint16_ITEMS 761
#define PQCLEAN_SNTRUP761_CLEAN_crypto_encode_761xint16_ITEMBYTES 2

void PQCLEAN_SNTRUP761_CLEAN_crypto_encode_761xint16(unsigned char *s, const void *v);
#endif
